// Copyright 2022 tison <wander4096@gmail.com>.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

use crate::{subscriber::Subscriber, subscription::Subscription};

pub struct MockSubscriber {
    request: u64,
}

impl MockSubscriber {
    pub fn new(request: u64) -> Self {
        MockSubscriber { request }
    }
}

impl Subscriber for MockSubscriber {
    type Error = ();
    type Item = u64;

    fn on_subscribe<S: Subscription>(&self, s: &S) {
        println!("on_subscribe");
        s.request(self.request);
    }

    fn on_next(&self, t: Self::Item) {
        println!("on_next: {:?}", t)
    }

    fn on_error(&self, e: Self::Error) {
        println!("on_error: {:?}", e)
    }

    fn on_completed(&self) {
        println!("on_completed")
    }
}
